@@ -16,7 +16,7 @@ has missing_after => 86400;
 has remove_after  => 864000;
 has tasks         => sub { {} };
 
-our $VERSION = '3.02';
+our $VERSION = '3.03';
 
 sub add_task { ($_[0]->tasks->{$_[1]} = $_[2]) and return $_[0] }
 
@@ -50,9 +50,9 @@ sub new {
 }
 
 sub perform_jobs {
-  my $self   = shift;
+  my ($self, $options) = @_;
   my $worker = $self->worker;
-  while (my $job = $worker->register->dequeue(0)) { $job->perform }
+  while (my $job = $worker->register->dequeue(0, $options)) { $job->perform }
   $worker->unregister;
 }
 
@@ -348,9 +348,22 @@ Construct a new L<Minion> object.
 =head2 perform_jobs
 
   $minion->perform_jobs;
+  $minion->perform_jobs({queues => ['important']});
 
 Perform all jobs, very useful for testing.
 
+These options are currently available:
+
+=over 2
+
+=item queues
+
+  queues => ['important']
+
+One or more queues to dequeue jobs from, defaults to C<default>.
+
+=back
+
 =head2 repair
 
   $minion = $minion->repair;
